using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using System.Data.SqlClient;

public partial class MovieDetails : System.Web.UI.Page {

    /// <summary>
    /// Code to be executed when page is loaded
    /// </summary>
    protected void Page_Load(object sender, EventArgs e) {
        // For this page, we need to get an argument out of they query string.
        int movieId = 0;
        try {
            movieId = int.Parse(Request.QueryString["Movie"]);
        } catch {
            // Query string was malformed, redirect to default
            Response.Redirect("Default.aspx");
        }

        // Create a database connection object.  
        // Uses a connection string specified in Web.Config/configuration/appSettings/connectionStrings
        SqlConnection myConn = new SqlConnection(ConfigurationManager.ConnectionStrings["ImdbString"].ConnectionString);

        // Create a dataset to store offline instance of data
        DataSet ds = new DataSet();

        // Declare a query. This will return details for this movie
        string detailsQuery = String.Format(@"
            SELECT m.* 
            FROM IMDB.dbo.Movie m 
            WHERE m.id = {0}",movieId);

        // Declare a query. This will return the cast of this movie
        string castQuery = String.Format(@"
            SELECT a.*, c.* 
            FROM IMDB.dbo.Actor a
	            JOIN IMDB.dbo.Cast c ON a.id = c.pid 
            WHERE mid = {0}
            ORDER BY lname ASC", movieId);

        // Declare a query. This will return the directors of this movie
        string directorsQuery = String.Format(@"
            SELECT d.* 
            FROM IMDB.dbo.Directors d
	            JOIN IMDB.dbo.Movie_Directors md ON d.id = md.did 
            WHERE mid = {0}
            ORDER BY lname ASC", movieId);

        // Create new data adapters for interfacing between our online data (in database) and offline
        // data (in dataset)
        SqlDataAdapter detailsAdapter = new SqlDataAdapter(detailsQuery, myConn);
        SqlDataAdapter castAdapter = new SqlDataAdapter(castQuery, myConn);
        SqlDataAdapter directorsAdapter = new SqlDataAdapter(directorsQuery, myConn);

        // Specify to fill the table in the dataset using the querys
        detailsAdapter.Fill(ds, "Movie");
        castAdapter.Fill(ds, "Cast");
        directorsAdapter.Fill(ds, "Directors");

        // Make sure the database returned movie details
        if (ds.Tables["Movie"].Rows.Count == 0) {
            throw new ApplicationException("Invalid Movie ID");
        } else if (ds.Tables["Movie"].Rows.Count > 1) {
            throw new ApplicationException("Ambiguous Movie ID");
        }

        // Assign movie details to local field 
        movieDetails = ds.Tables["Movie"].Rows[0];

        // Set the table in the dataset to be the datasouce for a 'repeater' objects on the page
        castRepeater.DataSource = ds.Tables["Cast"];
        directorRepeater.DataSource = ds.Tables["Directors"];

        // Cuase the data in the table to be copied into the repeater 
        DataBind();
    }

    public DataRow movieDetails;

}
